<?php


namespace Controller;

use Traits\TResponse;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Budget
{
    use TResponse;

    /**
     * @var \Service\Budget
     */
    private $budgetService;

    public function __construct(\Service\Budget $budgetService)
    {
        $this->budgetService = $budgetService;
    }

    public function budgetItems(Request $request, Response $response) {
        try{
            $budgetItems = $this->budgetService->budgetItem();
            $this->sendResponse($budgetItems, 200);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function classificationBudgetItem(Request $request, Response $response) {
        try{
            $params = $request->getParameters();
            $classificationId = $params['ID'];
            $budgetItems = $this->budgetService->classificationBudgetItem($classificationId);
            $this->sendResponse($budgetItems, 200);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function budgetItemSave(Request $request, Response $response) {
        $params = $request->getParameters();
        try{
            $id = $params['ID'];
            $name = $params['NAME'];
            $valueItem = $params['VALUE_ITEM'];
            $unitMeasure = $params['UNIT_MEASURE'];
            $status = $params['STATUS'];
            $this->budgetService->budgetItemSave($id,$name,$valueItem,$unitMeasure,$status);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function budgetItemRemove(Request $request, Response $response) {
        try {
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $id = $param['ID'];
                $this->budgetService->budgetItemRemove($id);
            }
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function addBudgetItemInClassificationSave(Request $request, Response $response) {
        try{
            $params = $request->getParameters();
            $id = $params['ID'];
            $classification = $params['CLASSIFICATION'];
            $this->budgetService->addBudgetItemInClassificationSave($id,$classification);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function classificationBudgetItemRemove(Request $request, Response $response) {
        try{
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $id = $param['ID'];
                $this->budgetService->classificationBudgetItemRemove($id);
            }
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
