<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\DevOps\Model\Projectmanagement\Entities;

class TaskType
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * TaskTracking constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function findTaskType($organizationId, $conditions = '')
    {
        $query = <<<SQL
			SELECT
          CASE
                    WHEN TT.CONTROL = 'T' THEN 'Não iniciada'
                    WHEN TT.CONTROL = 'B' THEN 'Backlog'
                    WHEN TT.CONTROL = 'I' THEN 'Em andamento'
                    WHEN TT.CONTROL = 'D' THEN 'Concluída'
                    WHEN TT.CONTROL = 'H' THEN 'Homologado'
                    ELSE ''
          END AS CONTROL_NAME,
          CASE
                    WHEN TT.ALLOW_CLOSE_ISSUE = 'Y' THEN 'Sim'
                    WHEN TT.ALLOW_CLOSE_ISSUE = 'N' THEN 'Não'
                    ELSE ''
          END AS ALLOW_CLOSE_ISSUE_NAME,
          CASE
                    WHEN TT.ALLOW_PLAY_TASK = 'Y' THEN 'Sim'
                    WHEN TT.ALLOW_PLAY_TASK = 'N' THEN 'Não'
                    ELSE ''
          END AS ALLOW_PLAY_TASK_NAME,
          TT.ALLOW_PLAY_TASK_IN_FRAME,
          TT.ID ,
          TT.ORGANIZATION ,
          TT.CONTROL ,
          TT.LABEL ,
          TT.SYSTEM ,
          RES.NAME                             AS CREATED_BY ,
          To_char(TT.CREATED_AT, 'DD/MM/YYYY') AS CREATED_AT ,
          TT.UPDATED_BY ,
          TT.UPDATED_AT ,
          TT.IS_ISSUE ,
          TT.PROJECT ,
          TT.IS_PROJECT ,
          TT.INITIAL_TASK_STATUS ,
          TT.ORDER_TO_FRAME ,
          TT.ALLOW_CLOSE_ISSUE ,
          TT.ORDER_TO_VIEW ,
          TT.TIME_AUTO_CHANGE_STATUS        AS DAY_NUMBERS,
          TST.LABEL                         AS TARGET_STATUS_NAME,
          TST.ID                            AS TARGET_STATUS,
          TT.DESCRIPTION_AUTO_CHANGE_STATUS AS DESCRIPTION,
          TT.ALLOW_PLAY_TASK,
          (
                     SELECT     RTRIM(XMLAGG(Xmlelement(E,CLT.ID,',').EXTRACT('//text()') ORDER BY CLT.ID).GETCLOBVAL(),',')
                     FROM       TASK_TYPE_CLASSIFICATION TTC
                     INNER JOIN CLASSIFICATION CLT
                     ON         (
                                           CLT.ID = TTC.CLASSIFICATION_ID)
                     WHERE      TT.ID = TTC.TASK_TYPE_ID
                     AND        TTC.TASK_ISSUE_CLASSIF = 'T' ) AS TASK_CLASSIFICATION,
          (
                     SELECT     RTRIM(XMLAGG(XMLELEMENT(E,CLT.ID,',').EXTRACT('//text()') ORDER BY CLT.ID).GETCLOBVAL(),',')
                     FROM       TASK_TYPE_CLASSIFICATION TTC
                     INNER JOIN CLASSIFICATION CLT
                     ON         (
                                           CLT.ID = TTC.CLASSIFICATION_ID)
                     WHERE      TT.ID = TTC.TASK_TYPE_ID
                     AND        TTC.TASK_ISSUE_CLASSIF = 'I' ) AS ISSUE_CLASSIFICATION
FROM      TASK_TYPE TT
LEFT JOIN TASK_STATUS TST
ON        (
                    TST.ID = TT.TASK_STATUS_AUTO_CHANGE_STATUS)
JOIN      RESOURCE_T RES
ON        (
                    RES.ID = TT.CREATED_BY)
SQL;

        $params = array(
            'organizationId' => $organizationId
        );

        $types = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
        
        foreach ($types['data'] as &$type) {
            $type['ISSUE_CLASSIFICATION'] = !empty($type['ISSUE_CLASSIFICATION']) ? explode(',', $type['ISSUE_CLASSIFICATION'])  : null;
            $type['TASK_CLASSIFICATION'] = !empty($type['TASK_CLASSIFICATION']) ? explode(',', $type['TASK_CLASSIFICATION'])  : null;
        }

        return $types;
    }

    public function findEntranceCommentIssueStatus($issueStatusId){
        $query = <<<SQL
    SELECT TTCT.ID ,
           TTCT.TASK_TYPE_ID AS TASK_TYPE,
           TTCT.COMMENT_TYPE_ID AS COMMENT_TYPE,
           TTCT.IN_OUT_COMMENT ,
           TTCT.ACTION_LABEL ,
           TTCT.STATUS ,
           TTCT.COMMENT_DESCRIPTION AS DESCRIPTION ,
           TTCT.TASK_TYPE_TARGET,
           COTY.NAME AS COMMENT_TYPE_NAME,
          ( SELECT
           rtrim(xmlagg(xmlelement(e,TTCC.CLASSIFICATION_ID  ,',').extract('//text()') order by TTCC.CLASSIFICATION_ID ).GetClobVal(),',') AS ISSUE_CLASSIFICATION
           FROM TASK_TYPE_COMMENT_TYPE_CLASSIF TTCC
           WHERE TTCC.TASK_TYPE_COMMENT_TYPE_ID = TTCT.ID ) AS ISSUE_CLASSIFICATION
      FROM TASK_TYPE_COMMENT_TYPE TTCT
 LEFT JOIN COMMENT_TYPE COTY ON (COTY.ID = TTCT.COMMENT_TYPE_ID )
     WHERE TTCT.TASK_TYPE_ID = :taskType
       AND TTCT.IN_OUT_COMMENT = :IN_COMMENT

SQL;
        $params = array(
            'taskType' => $issueStatusId,
            'IN_COMMENT' => Entities\TaskTypeCommentType::IN_COMMENT
        );
        $return = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
        foreach ($return["data"] as $item) {
            $item['ISSUE_CLASSIFICATION'] = Utilities::setSelectMultiInQuery($item['ISSUE_CLASSIFICATION']);
        }
        return $return;
    }

    public function findIssueFramingClassification($issueStatusId){
        $query = <<<SQL
         SELECT TAT.ID ,
                TAT.TASK_TYPE_ID ,
                TAT.CLASSIFICATION_ID ,
                TAT.TASK_ISSUE_CLASSIF,
                CLA.LABEL,
                CLA.LABEL AS LABEL_FORM
           FROM TASK_TYPE_CLASSIFICATION TAT
           JOIN CLASSIFICATION CLA ON(CLA.ID = TAT.CLASSIFICATION_ID)
          WHERE TAT.TASK_TYPE_ID = :issueStatusId
            AND TAT.TASK_ISSUE_CLASSIF = :type
       ORDER BY ID ASC
SQL;
        $params = array(
            'issueStatusId' => $issueStatusId,
            'type' => Entities\TaskTypeClassification::TYPE_LOCKED,
        );
        $return = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);

        return $return;
    }

    public function findOutputCommentIssueStatus($issueStatusId){
        $query = <<<SQL
    SELECT TTCT.ID ,
           TTCT.TASK_TYPE_ID AS TASK_TYPE,
           TTCT.COMMENT_TYPE_ID AS COMMENT_TYPE,
           TTCT.IN_OUT_COMMENT ,
           TTCT.ACTION_LABEL ,
           TTCT.STATUS ,
           TTCT.COMMENT_DESCRIPTION AS DESCRIPTION ,
           TTCT.TASK_TYPE_TARGET AS TARGET_STATUS,
           TAST.LABEL AS TARGET_STATUS_NAME,
           COTY.NAME AS COMMENT_TYPE_NAME,
          ( SELECT
           rtrim(xmlagg(xmlelement(e,TTCC.CLASSIFICATION_ID  ,',').extract('//text()') order by TTCC.CLASSIFICATION_ID ).GetClobVal(),',') AS ISSUE_CLASSIFICATION
           FROM TASK_TYPE_COMMENT_TYPE_CLASSIF TTCC
           WHERE TTCC.TASK_TYPE_COMMENT_TYPE_ID = TTCT.ID ) AS ISSUE_CLASSIFICATION
      FROM TASK_TYPE_COMMENT_TYPE TTCT
 LEFT JOIN COMMENT_TYPE COTY ON (COTY.ID = TTCT.COMMENT_TYPE_ID )
 LEFT JOIN TASK_TYPE TAST ON (TAST.ID = TTCT.TASK_TYPE_TARGET )
     WHERE TTCT.TASK_TYPE_ID = :taskType
       AND TTCT.IN_OUT_COMMENT = :OUT_COMMENT

SQL;
        $params = array(
            'taskType' => $issueStatusId,
            'OUT_COMMENT' => Entities\TaskTypeCommentType::OUT_COMMENT,
        );
        $return = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
        foreach ($return['data'] as &$item) {
            $item['ISSUE_CLASSIFICATION'] = !empty($item['ISSUE_CLASSIFICATION']) ? explode(',', $item['ISSUE_CLASSIFICATION'])  : null;
        }
        return $return;
    }
}
