<?php


namespace Service;

use Util\InstanceProvider;
use Zeedhi\Framework\Session\Session;
use \Util\Utilities;
use Exception;
use \Doctrine\ORM\EntityManager;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;
use Zeedhi\DevOps\Model\Projectmanagement\Entities;


class Organization
{
    /**
     * @var Utilities
     */
    private $environment;
     /**
     * @var EntityManager
     */
    public $entityManager;



    public function __construct()
    {
        $this->environment    = InstanceProvider::getEnvironment();
        $this->entityManager  = InstanceProvider::getEntityManager();

    }

    public function findOrganizacaoInfo(){
        $nrOrg          = Utilities::getEnvironment()->getCurrentOrganizationId();
        $organizacaoRepository = InstanceProvider::getRepository()->getOrganization();

        return $organizacaoRepository->getOrganization($nrOrg);
    }

    public function findDefaultCalendar(){
        $nrOrg          = Utilities::getEnvironment()->getCurrentOrganizationId();
        $organizacaoRepository = InstanceProvider::getRepository()->getOrganization();

        return $organizacaoRepository->getDefaultCalendar($nrOrg, 'D');

    }

    public function saveOrganizacaoInfo($name, $foundation, $document, $description, $managers, $calendarId,
        $calendarDefaultId, $structureId, $timeSheetRequired = 'N',
        $replicateTimeSheetRequired = false){
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            /** @var \Zeedhi\DevOps\Model\Projectmanagement\Entities\Organization $organization */
            $organization = $this->environment->getCurrentOrganization();
            /** @var \Zeedhi\DevOps\Model\Projectmanagement\Entities\Structure $structure */
            $structure = InstanceProvider::getRepository()->getStructure()->find($structureId);
            $structure->setName($name);
            $structure->setTimeSheetRequired($timeSheetRequired);
            $this->entityManager->persist($structure);
            //$this->structureService->saveEditCalendar($calendarId, $calendarDefaultId, $structureId);
            $structureService = InstanceProvider::getService()->getStructure();
            $structureService->setManager($structureId, $managers);
            $organization = $this->updateOrganization($organization, $name, $foundation, $organization->getStatus(),
                $document, $description);
            //$this->structureService->setTimeSheetRequired($replicateTimeSheetRequired, $structure,$timeSheetRequired);
            $this->entityManager->flush();
            $connection->commit();
        }catch (\Exception $e){
            $connection->rollBack();
            throw $e;
        }
        return array(
            'userName' => $this->environment->getCurrentUser()->getName(),
            'organizationName' => $organization->getName()
        );
        
    }

    public function updateOrganization($organization, $name, $foundation, $status, $document, $description, $creator = null) {
        $organizationModel = '\Zeedhi\DevOps\Model\Projectmanagement\Entities\Organization';
        $organizationFactory = InstanceProvider::getFactory()->getOrganization();

        if(!($organization instanceOf $organizationModel)){
            $organization = $this->entityManager->find($organizationModel, $organization);
        }
        $entity = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Organization')
            ->findOneBy(array("name" => $name));

        if(empty($entity) || $entity->getId() === $organization->getId()){
            $entity = $organizationFactory->updateOrganization($organization, $name, $foundation, $status, $document, $description, $creator);
            $this->entityManager->persist($entity);
            $this->entityManager->flush();
        } else{
            throw new \Exception('já existe uma organização com o nome ' . $entity->getName() . '.', 1);
        }

        return $entity;
    }
}