<?php

namespace Service;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Factory\Priority as PriorityFactory;

class Priority
{

    private $entityManager;
    private $environment;
    /** @var  \Factory\Priority $priorityFactory */
    protected $priorityFactory;

    /**
     * TaskTracking constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager, PriorityFactory $priorityFactory)
    {
        $this->environment = InstanceProvider::getEnvironment();
        $this->entityManager = $entityManager;
        $this->priorityFactory = $priorityFactory;
    }

    public function findIssuePriority()
    {
        return InstanceProvider::getRepository()->getLocalPriority()->findIssuePriority($this->environment->getCurrentOrganizationId());
    }

    public function removeIssuePriority($id)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $priority = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Priority')->findOneBy(array('id' => $id));
            $this->entityManager->remove($priority);
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function createIssuePriority($priorityLabel, $priorityColor)
    {
        try {
            $priorityEntity = $this->priorityFactory->createIssuePriority($priorityLabel, $priorityColor);
            $this->entityManager->persist($priorityEntity);
            $this->entityManager->flush();
        } catch (\Exception $ex) {
            throw $ex;
        }
    }

    public function updateIssuePriority($priorityId, $priorityName, $priorityColor)
    {
        try {
            $priorityEntity = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Priority')->findBy(array('id' => $priorityId))[0];
            $priorityEntity = $this->priorityFactory->updateIssuePriority($priorityEntity, $priorityName, $priorityColor);
            $this->entityManager->persist($priorityEntity);
            $this->entityManager->flush();
        } catch (\Exception $ex) {
            throw $ex;
        }
    }
}
