import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { DialogService, LoadingService, Modal, ModalService } from '@zeedhi/common';
import { Http, Loader } from '@zeedhi/core';
import Messages from '@/services/Messages';
import { InstanceService } from '@/services/InstanceService';
import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { Utilities } from '@/services/Utilities';

export class DependenciaSolicitacaoController {
    public demandManagementController = Loader.getInstance('DemandManagementController');

    private modalAddDependenciaSoli!: Modal;

    private modalSoliPesq!: Modal;

    public async addDependenciaSoli() {
        this.modalAddDependenciaSoli = await ModalService.createFromJsonPost('', { jsonPath: 'demandManagement/modal/addDependenciaSoliModal' });
        await this.modalAddDependenciaSoli.show();
    }

    public closeModalAddDependenciaSoli() {
        this.modalAddDependenciaSoli.hide();
        this.modalAddDependenciaSoli.destroy();
    }

    public async changeSolicitacao(params: any) {
        if (params.component.value) {
            params.component.value = `0000000000${params.component.value}`.slice(-10);
            try {
                const response = await Http.get(`findAllSoliserv?page=1&limit=25&search=${params.component.value}&search_in%5B0%5D=NRSOLISERV`);
                if (!response.data.data[0]) {
                    DialogServiceCustom.showError(Messages.ERROR_SOLI);
                }
            } catch (e) {
                DialogServiceCustom.showErrorBackend(e);
            }
        }
    }

    public async clickSolicitacaoPesq() {
        this.modalSoliPesq = await ModalService.createFromJsonPost('', { jsonPath: 'demandManagement/modal/modalSoliPesq' });
        await this.modalSoliPesq.show();
    }

    public closeModalSoliPesq() {
        this.modalSoliPesq.hide();
        this.modalSoliPesq.destroy();
    }

    public async rowClickModalSoliPesq(params: any) {
        const formAddDependenciaSoliModal = InstanceService.getInstanceZdForm('formAddDependenciaSoliModal');
        formAddDependenciaSoliModal.value.solicitacao = params.row.NRSOLISERV;
        this.closeModalSoliPesq();
    }

    public qryAgrupaSoliBeforeInsert() {
        const formAddDependenciaSoliModal = InstanceService.getInstanceZdForm('formAddDependenciaSoliModal');
        const checkValidation = formAddDependenciaSoliModal.validate();
        if (checkValidation) {
            LoadingService.show();
            Http.post('/qryAgrupaSoliBeforeInsert', {
                NRSOLISERV: this.demandManagementController.callRelationship,
                NRSOLISERVGRID: formAddDependenciaSoliModal.value.solicitacao,
            }).then((retorno) => {
                console.warn(retorno);
                LoadingService.hide();
                const message = `A solicitação ${retorno.data.NRSOLISERV} possui dependência com outras solicitações. Deseja que a solicitação ${retorno.data.NRSOLISERVGRID} tenha dependencia com essas solicitações?`;
                DialogService.show({
                    name: 'dialog-agrupa-soli',
                    type: 'warning',
                    title: 'Atenção',
                    text: message,
                    buttons: [
                        {
                            name: 'NAO',
                            component: 'ZdButton',
                            label: 'Não',
                            outline: true,
                            events: {
                                click: () => {
                                    DialogService.hide();
                                },
                            },
                        },
                        {
                            name: 'SIM',
                            component: 'ZdButton',
                            label: 'Sim',
                            events: {
                                click: () => {
                                    this.qryAgrupaSoliInsert(retorno.data);
                                    DialogService.hide();
                                },
                            },
                        },
                    ],
                });
            }).catch((e: any) => {
                LoadingService.hide();
                DialogServiceCustom.showErrorBackend(e);
            });
        } else {
            DialogServiceCustom.messageErrorValidate();
        }
    }

    public async qryAgrupaSoliInsert(params: any) {
        LoadingService.show();
        const gridDependenciaSoli = InstanceService.getInstanceTekGrid('gridDependenciaSoli');
        try {
            await Http.post('/qryAgrupaSoliInsert', {
                CDFILIAL: params.CDFILIAL,
                CDOPERINCL: params.CDOPERINCL,
                NRSEQAGRUPASOLI: params.NRSEQAGRUPASOLI,
                NRSOLISERV: params.NRSOLISERV,
                NRSOLISERVGRID: params.NRSOLISERVGRID,
            });
            this.closeModalAddDependenciaSoli();
            AlertServiceCustom.defaultSaveSuccessAlert();
            gridDependenciaSoli.datasource.get();
        } catch (e) {
            LoadingService.hide();
            DialogServiceCustom.showErrorBackend(e);
        }
        LoadingService.hide();
        console.warn(params);
    }

    public async beforeDeleteDependenciaSoli(params:any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: (() => {
						DialogService.hide();
						this.excluirDependenciaSoli();
					}),
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

    public async excluirDependenciaSoli() {
        const gridDependenciaSoli = InstanceService.getInstanceTekGrid('gridDependenciaSoli');
        LoadingService.show();
        try {
            await Http.post('/qryAgrupaSoliDelete', {
                ROWS: gridDependenciaSoli.selectedRows,
                NRSOLISERV: this.demandManagementController.callRelationship,
            });
            await gridDependenciaSoli.datasource.get();
            gridDependenciaSoli.selectedRows = [];
        } catch (e) {
            LoadingService.hide();
            DialogServiceCustom.showErrorBackend(e);
        }
        LoadingService.hide();
    }
}
