import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { InstanceService } from '@/services/InstanceService';
import { Utilities } from '@/services/Utilities';
import { DialogService, LoadingService, Modal, ModalService, Text } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import Messages from '@/services/Messages';

export class IssueLabelsController {
    private modalIssueLabels!: Modal;

    public async exibirModalIssueLabels() {
        this.modalIssueLabels = await ModalService.createFromJsonPost('', { jsonPath: 'issueLabels/modal/issueLabelsModal' });
        this.modalIssueLabels.show();
    }

    public closeModalIssueLabels() {
        this.modalIssueLabels.hide();
        this.modalIssueLabels?.destroy();
    }

    public async abrirModalIssueLabelsAdd() {
        await this.exibirModalIssueLabels();
        Metadata.getInstance<Text>('headerTitleIssueLabelsModal').text = 'Adicionar Rótulo';
    }

    public async abrirModalIssueLabelsEdit({ row }: any) {
        await this.exibirModalIssueLabels();
        Metadata.getInstance<Text>('headerTitleIssueLabelsModal').text = 'Edição do Rótulo';
        InstanceService.getInstanceTextInput('formIssueLabelsModal-DESCRIPTION').value = row.DESCRIPTION;
        InstanceService.getInstanceZdSelect('formIssueLabelsModal-PROJECT_NAME').value = row.PROJECT;
        InstanceService.getInstanceZdSelect('formIssueLabelsModal-ID').value = row.ID;
    }

    public setTypeName({ component }: any) {
        if (component.value === null) {
            InstanceService.getInstanceTextInput('formIssueLabelsModal-LABEL').value = null;
        } else {
            InstanceService.getInstanceTextInput('formIssueLabelsModal-LABEL').value = component.selectValue.TYPE_NAME;
        }
    }

    public async saveIssueLabels() {
        const formIssueLabelsModal = InstanceService.getInstanceZdForm('formIssueLabelsModal');
        const checkValidation = formIssueLabelsModal.validate();
        if (checkValidation) {
            const issueLabelsGrid = InstanceService.getInstanceTekGrid('issueLabelsGrid');
            LoadingService.show();
            try {
                await Http.post('/saveIssueLabels', {
                    ID: InstanceService.getInstanceTextInput('formIssueLabelsModal-ID').value,
                    DESCRIPTION: InstanceService.getInstanceZdSelect('formIssueLabelsModal-DESCRIPTION').value,
                    IDPROJECT: InstanceService.getInstanceZdSelect('formIssueLabelsModal-PROJECT_NAME').value,
                });
                this.closeModalIssueLabels();
                AlertServiceCustom.defaultSaveSuccessAlert();
                await issueLabelsGrid.datasource.get();
            } catch (e) {
                LoadingService.hide();
                DialogServiceCustom.showErrorBackend(e);
            }
            LoadingService.hide();
        } else {
            DialogServiceCustom.messageErrorValidate();
        }
    }

    public async beforeDeleteIssueLabels() {
        const buttonYes = [
            {
                name: Utilities.getNameDynamic('yes-'),
                component: 'ZdButton',
                label: 'Sim',
                events: {
                    click: (() => {
                        DialogService.hide();
                        this.removeIssueLabels();
                    }),
                },
            },
        ];
        DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
    }

    public async removeIssueLabels() {
        const issueLabelsGrid = InstanceService.getInstanceTekGrid('issueLabelsGrid');
        LoadingService.show();
        try {
            await Http.post('/removeIssueLabels', {
                ROWS: issueLabelsGrid.selectedRows,
            });
            issueLabelsGrid.selectedRows = [];
            issueLabelsGrid.datasource.get();
        } catch (e) {
            LoadingService.hide();
            DialogServiceCustom.showErrorBackend(e);
        }
        LoadingService.hide();
    }

    public async saveDescricaoGrid() {
        const issueLabelsGrid = InstanceService.getInstanceTekGrid('issueLabelsGrid');
        LoadingService.show();
        try {
            await Http.post('/saveDescricaoGrid', {
                ROWS: issueLabelsGrid.getEditedRows(),
            });
            issueLabelsGrid.cancelEditedRows();
            issueLabelsGrid.datasource.get();
        } catch (e) {
            LoadingService.hide();
            DialogServiceCustom.showErrorBackend(e);
        }
        LoadingService.hide();
    }
}
