import { Config, Http, Metadata } from '@zeedhi/core';
import { InstanceService } from '@/services/InstanceService';
import {
	TekRestDatasource,
	ITekGridLayout,
} from '@zeedhi/teknisa-components-common';
import { ITabsBeforeChangeEventParam, LoadingService } from '@zeedhi/common';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { AlertServiceCustom } from '@/services/AlertServiceCustom';

export class TaskTrackingController {
	public showTaskTrackingForm = false;

	public isLoadingDefault = false;

	public taskDescription = '';

	public taskId = '';

	public taskResource = '';

	public baseUrl = '';

	public disableResponseField = false;

	public currentUserId = '';

	get isVisibleTaskTrackingGrid() {
		return !this.showTaskTrackingForm;
    }

	get getDisableResponseField() {
		return this.disableResponseField;
	}

	public getValueMask(value: any) {
		let time = '';
		if (value) {
			const hours = parseInt(value) / 3600;
			if (hours >= 1) {
				time += `${Math.round(hours)}H`;
			}
			let minutes = (hours - Math.round(hours)) * 60;
			let seconds = (minutes - Math.round(minutes)) * 60;
			seconds = Math.round(seconds);
			if (seconds === 60) {
				minutes += 1;
				seconds = 0;
			}
			if (minutes >= 1) {
				time += `${Math.round(minutes)}m`;
			}
			if (seconds >= 1) {
				time += `${seconds}s`;
			}
		} else {
			time = value;
		}
		return time;
	}

    public async onMountedDemandManagementGrid() {
		const callGridInstance = InstanceService.getInstanceTekGrid('gridTaskTracking');
		if (callGridInstance.datasource instanceof TekRestDatasource) {
			const dynamicFilter = {
				STATUS: [
					{
						operation: 'CONTAINS',
						relation: 'AND',
						value: 'A',
					},
				],
				PERIOD: [
					{
						operation: 'BETWEEN',
						relation: 'AND',
						value: ['03/08/2023', '10/08/2023'],
					},
				],
                STATUS_RESOURCE: [
					{
						operation: 'EQUALS',
						relation: 'AND',
						value: 'A',
					},
				],
			};
			const defaultLayout: ITekGridLayout = {
				name: 'Padrão',
				dynamicFilter,
			};
			callGridInstance.layoutOptions?.updateDefaultLayout(defaultLayout);
		}
	}

	public async rowClickGridTaskTracking(params: any) {
		const callGridInstance = InstanceService.getInstanceTekGrid('gridTaskTracking');
		if (callGridInstance.editing === true) return;
		LoadingService.show();
		this.taskDescription = params.row.TASK_NAME;
		this.showTaskTrackingForm = true;
		this.taskId = params.row.TASK_ID;
		this.taskResource = params.row.RESOURCE_T;

		try {
			const callData = await Http.post('infoTaskInTaskTracking', { TASK_ID: this.taskId, RESOURCE_T: this.taskResource });
			this.currentUserId = callData.data[0].USER_ID;
			this.disableResponseField = (callData.data[0].RESOURCE.indexOf(this.currentUserId) < 0);
			LoadingService.hide();
			this.getSelectsEdit(callData);
			const tabMainFormTaskTracking = { component: null };
			tabMainFormTaskTracking.component = Metadata.getInstance<any>('tabMainTaskTracking');
			this.onCreatedIterableComments(tabMainFormTaskTracking);
		} catch (e) {
			LoadingService.hide();
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public async getSelectsEdit(callData: any) {
		const taskFormInstance = InstanceService.getInstanceZdForm('formTaskTracking');
		const dataCallData = callData.data[0];
		taskFormInstance.value.TASK_ID = dataCallData.ID;
		taskFormInstance.value.CREATED_BY = dataCallData.CREATED_BY;
		taskFormInstance.value.CREATED_AT = dataCallData.CREATED_AT;
		taskFormInstance.value.NAME = dataCallData.NAME;
		taskFormInstance.value.STATUS_CHECK_BOX = dataCallData.STATUS;
		taskFormInstance.value.TASK_STATUS_ALLOCATION_NAME = dataCallData.TASK_STATUS_NAME;
		taskFormInstance.value.RESOURCE = dataCallData.RESOURCE;
		taskFormInstance.value.NAME_RESOURCE = dataCallData.NAME_RESOURCE;
		taskFormInstance.value.TOTAL_TIME = dataCallData.TOTAL_TIME;
		taskFormInstance.value.START = dataCallData.START;
		taskFormInstance.value.END = dataCallData.END;
		taskFormInstance.value.TIME_PLANNED = dataCallData.TIME_PLANNED;
		taskFormInstance.value.TASK_CLASSIFICATION_LABEL = dataCallData.TASK_CLASSIFICATION_LABEL;
		taskFormInstance.value.PERCENT_COMPLETED = dataCallData.PERCENT_COMPLETED;
		taskFormInstance.value.DATE_EXCEPTION_NAME = dataCallData.DATE_EXCEPTION_NAME;
		taskFormInstance.value.TYPE_RELATIONSHIP = dataCallData.TYPE_RELATIONSHIP;
		taskFormInstance.value.DESCRIPTION = dataCallData.DESCRIPTION;
		taskFormInstance.value.TASK_LABEL = dataCallData.TASK_LABEL;
		taskFormInstance.value.TASK_RESPONSE = dataCallData.TASK_RESPONSE;
	}

	public resetAllValues() {
		const callFormInstance = InstanceService.getInstanceZdForm('formTaskTracking');
		callFormInstance.value.ID = '';
		callFormInstance.value.CREATED_BY = '';
		callFormInstance.value.CREATED_AT = '';
		callFormInstance.value.NAME = '';
		callFormInstance.value.STATUS_CHECK_BOX = '';
		callFormInstance.value.TASK_STATUS_ALLOCATION_NAME = '';
		callFormInstance.value.RESOURCE = '';
		callFormInstance.value.NAME_RESOURCE = '';
		callFormInstance.value.TOTAL_TIME = '';
		callFormInstance.value.START = '';
		callFormInstance.value.END = '';
		callFormInstance.value.TIME_PLANNED = '';
		callFormInstance.value.PARENT_NAME = '';
		callFormInstance.value.TASK_CLASSIFICATION_LABEL = '';
		callFormInstance.value.PERCENT_COMPLETED = '';
		callFormInstance.value.DATE_EXCEPTION_NAME = '';
		callFormInstance.value.DATE_EXCEPTION = '';
		callFormInstance.value.TASK_GENERATOR_NAME = '';
		callFormInstance.value.TYPE_RELATIONSHIP = '';
		callFormInstance.value.TASK_LABEL = '';
		callFormInstance.value.DESCRIPTION = '';
		callFormInstance.value.TASK_RESPONSE = '';
		callFormInstance.value.ERROR_CLASSIFICATION = '';
	}

	public clickBackCardFormTaskTracking() {
		this.showTaskTrackingForm = false;
		this.resetAllValues();
		const tabsInstance = Metadata.getInstance<ITabsBeforeChangeEventParam>('tabMainFormDemandManagement');
		tabsInstance.activeTab = 0;
	}

    public async saveEditTask() {
        const taskFormInstance = InstanceService.getInstanceZdForm('formTaskTracking');
        const checkValidation = taskFormInstance.validate();
        if (checkValidation) {
            try {
                await Http.post('/saveLabelTask', { ID: taskFormInstance.value.TASK_ID, TASK_LABEL: taskFormInstance.value.TASK_LABEL, TASK_RESPONSE: taskFormInstance.value.TASK_RESPONSE });
                AlertServiceCustom.defaultSaveSuccessAlert();
            } catch (e) {
                LoadingService.hide();
                DialogServiceCustom.showErrorBackend(e);
            }
            LoadingService.hide();
        } else {
            DialogServiceCustom.messageErrorValidate();
        }
	}

	public async changeGridAttachments() {
		let gridAttachments: any = null;
		gridAttachments = Metadata.getInstance<any>('gridTaskAttachments');

		gridAttachments.datasource.filter.task = this.taskId;

		try {
			await gridAttachments.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
	}

	public onCreatedIterableComments(params: any) {
		const tab = params.component.tabs[params.component.activeTab];
		setTimeout(async () => {
			if (tab.events && tab.events.change && typeof tab.events.change === 'function') {
				await tab.events.change(params);
			}
		}, 100);
	}

	public downloadFileGrid(params: any) {
		this.baseUrl = Config.env.endPoint;
		const downloadUri = `${this.baseUrl}/downLoadAttachment?ID=${params.row.ID}`;
		window.open(downloadUri);
	}
}
